@@ -1,6 +1,6 @@
 package Business::OnlinePayment::CashCow;
 
-# $Id: CashCow.pm,v 1.19 2005/10/17 10:41:21 jonasbn Exp $
+# $Id: CashCow.pm,v 1.20 2005/12/09 20:40:08 jonasbn Exp $
 
 use strict;
 use vars qw($VERSION @ISA);
@@ -12,7 +12,7 @@ use Data::Dumper;
 
 use constant DEBUG => 0;
 
-$VERSION = '0.03';
+$VERSION = '0.04';
 @ISA = qw(Business::OnlinePayment);
 
 sub set_defaults {
@@ -243,11 +243,21 @@ sub _process_response {
 		$ref = XMLin($page);
 	};
 
-	if ($@) {
+	if ($@ or not $ref) {
 		$self->error_message("Unable to handle result from CashCow gateway");
 		$self->is_success(0);
 	} else {
-		$self->is_success(1);
+
+		if (DEBUG) {
+			print STDERR Dumper $ref;
+		}
+
+		if ($ref->{errormessage}) {
+			$self->error_message($ref->{errormessage});
+			$self->is_success(0);
+		} else {
+			$self->is_success(1);
+		}
 	}
 
 	return 1;
